/*
 * Copyright (C) 2006-2009 Alex Lasnier <alex@fepg.org>
 *
 * This file is part of Radio Info
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __RADIO_INFO_H
#define __RADIO_INFO_H


#include <vdr/plugin.h>
#include <vdr/status.h>

#include "receiver.h" 
#include "osd.h"
#include "data.h"
#include "cache.h"


///////////////////////////////////////////////////////////////////////////////


class cPluginRadioinfo : public cPlugin, cStatus 
{  
public:
  cPluginRadioinfo(void);
  virtual ~cPluginRadioinfo();
  virtual const char* Version(void);
  virtual const char* Description(void);
  virtual const char* CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Initialize(void);
  virtual bool Start(void);
  virtual void Stop(void);
  virtual void Housekeeping(void);
  virtual const char* MainMenuEntry(void);
  virtual cOsdObject* MainMenuAction(void);
  virtual cMenuSetupPage* SetupMenu(void);
  virtual bool SetupParse(const char* Name, const char* Value);
  virtual bool Service(const char* Id, void* Data = NULL);
  virtual const char** SVDRPHelpPages(void);
  virtual cString SVDRPCommand(const char* Command, const char* Option, int& ReplyCode);

  void FoundInfoPid(int Pid);
  static cPluginRadioinfo* currentRadioInfo;
   
protected:
  virtual void ChannelSwitch(const cDevice* Device, int ChannelNumber);

private:
  void FindPid(void);
  
  cRadioInfoOsd* radioInfoOsd;
  cRadioInfoReceiver* radioInfoReceiver;
  cRadioInfoData radioInfoData;
  
  cChannel* currentChannel;
  cDevice*  currentDevice;
  
  PidCache pidCache;
};


///////////////////////////////////////////////////////////////////////////////


#endif //__RADIO_INFO_H
